@@ -48,11 +48,11 @@ static int _process_raid_event(struct dso_state *state, char *params, const char
 	while ((d = strchr(d, 'D'))) {
 		uint32_t dev = (uint32_t)(d - status->dev_health);
 
-		if (!(state->raid_devs[dev / 64] & (1 << (dev % 64))))
+		if (!(state->raid_devs[dev / 64] & (UINT64_C(1) << (dev % 64))))
 			log_error("Device #%u of %s array, %s, has failed.",
 				  dev, status->raid_type, device);
 
-		state->raid_devs[dev / 64] |= (1 << (dev % 64));
+		state->raid_devs[dev / 64] |= (UINT64_C(1) << (dev % 64));
 		d++;
 		dead = 1;
 	}
@@ -76,7 +76,7 @@ static int _process_raid_event(struct dso_state *state, char *params, const char
 
 		/* if repair goes OK, report success even if lvscan has failed */
 		if (!dmeventd_lvm2_run_with_lock(state->cmd_lvconvert)) {
-			log_info("Repair of RAID device %s failed.", device);
+			log_error("Repair of RAID device %s failed.", device);
 			r = 0;
 		}
 	} else {
