@@ -9,6 +9,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+# noinspection PyUnresolvedReferences
 import dbus
 # noinspection PyUnresolvedReferences
 from dbus.mainloop.glib import DBusGMainLoop
@@ -21,6 +22,8 @@ from testlib import *
 
 g_tmo = 0
 
+g_prefix = os.getenv('PREFIX', '')
+
 use_session = os.getenv('LVMDBUSD_USE_SESSION', False)
 
 if use_session:
@@ -29,10 +32,28 @@ else:
 	bus = dbus.SystemBus(mainloop=DBusGMainLoop())
 
 
+def std_err_print(*args):
+	sys.stderr.write(' '.join(map(str, args)) + '\n')
+	sys.stderr.flush()
+
+
+def vg_n():
+	return g_prefix + rs(8, '_vg')
+
+
+def lv_n(suffix=None):
+	if not suffix:
+		s = '_lv'
+	else:
+		s = suffix
+	return g_prefix + rs(8, s)
+
+
 def get_objects():
-	rc = {MANAGER_INT: [], PV_INT: [], VG_INT: [], LV_INT: [],
-			THINPOOL_INT: [], JOB_INT: [], SNAPSHOT_INT: [], LV_COMMON_INT: [],
-			CACHE_POOL_INT: [], CACHE_LV_INT: []}
+	rc = {
+		MANAGER_INT: [], PV_INT: [], VG_INT: [], LV_INT: [],
+		THINPOOL_INT: [], JOB_INT: [], SNAPSHOT_INT: [], LV_COMMON_INT: [],
+		CACHE_POOL_INT: [], CACHE_LV_INT: []}
 
 	manager = dbus.Interface(bus.get_object(
 		BUSNAME, "/com/redhat/lvmdbus1"),
@@ -63,14 +84,14 @@ class TestDbusService(unittest.TestCase):
 		# we are not mucking with someones data on their system
 		self.objs, self.bus = get_objects()
 		if len(self.objs[PV_INT]) == 0:
-			print('No PVs present exiting!')
+			std_err_print('No PVs present exiting!')
 			sys.exit(1)
 		if len(self.objs[MANAGER_INT]) != 1:
-			print('Expecting a manager object!')
+			std_err_print('Expecting a manager object!')
 			sys.exit(1)
 
 		if len(self.objs[VG_INT]) != 0:
-			print('Expecting no VGs to exist!')
+			std_err_print('Expecting no VGs to exist!')
 			sys.exit(1)
 
 		self.pvs = []
@@ -141,7 +162,7 @@ class TestDbusService(unittest.TestCase):
 		if not pv_paths:
 			pv_paths = [self.objs[PV_INT][0].object_path]
 
-		vg_name = rs(8, '_vg')
+		vg_name = vg_n()
 
 		vg_path = self.handle_return(
 			self.objs[MANAGER_INT][0].Manager.VgCreate(
@@ -270,7 +291,7 @@ class TestDbusService(unittest.TestCase):
 		if len(self.objs[PV_INT]) >= 2:
 			vg = self._vg_create(
 				[self.objs[PV_INT][0].object_path,
-				self.objs[PV_INT][1].object_path]).Vg
+					self.objs[PV_INT][1].object_path]).Vg
 
 			path = self.handle_return(
 				vg.Reduce(False, [vg.Pvs[0]], g_tmo, {})
@@ -319,12 +340,14 @@ class TestDbusService(unittest.TestCase):
 
 		for l in lv_paths:
 			lv_proxy = ClientProxy(self.bus, l).LvCommon
-			self.assertTrue(lv_proxy.Vg == vg.object_path, "%s != %s" %
-							(lv_proxy.Vg, vg.object_path))
+			self.assertTrue(
+				lv_proxy.Vg == vg.object_path, "%s != %s" %
+				(lv_proxy.Vg, vg.object_path))
 			full_name = "%s/%s" % (new_name, lv_proxy.Name)
 			lv_path = mgr.LookUpByLvmId(full_name)
-			self.assertTrue(lv_path == lv_proxy.object_path, "%s != %s" %
-							(lv_path, lv_proxy.object_path))
+			self.assertTrue(
+				lv_path == lv_proxy.object_path, "%s != %s" %
+				(lv_path, lv_proxy.object_path))
 
 	def _verify_hidden_lookups(self, lv_common_object, vgname):
 		mgr = self.objs[MANAGER_INT][0].Manager
@@ -337,8 +360,16 @@ class TestDbusService(unittest.TestCase):
 			if len(h_lv.HiddenLvs) > 0:
 				self._verify_hidden_lookups(h_lv, vgname)
 
-			# print("Hidden check %s %s" % (h, h_lv.Name))
 			full_name = "%s/%s" % (vgname, h_lv.Name)
+			# print("Hidden check %s" % (full_name))
+			lookup_path = mgr.LookUpByLvmId(full_name)
+			self.assertTrue(lookup_path != '/')
+			self.assertTrue(lookup_path == h_lv.object_path)
+
+			# Lets's strip off the '[ ]' and make sure we can find
+			full_name = "%s/%s" % (vgname, h_lv.Name[1:-1])
+			# print("Hidden check %s" % (full_name))
+
 			lookup_path = mgr.LookUpByLvmId(full_name)
 			self.assertTrue(lookup_path != '/')
 			self.assertTrue(lookup_path == h_lv.object_path)
@@ -354,7 +385,7 @@ class TestDbusService(unittest.TestCase):
 		self._verify_hidden_lookups(thin_pool.LvCommon, vg_name_start)
 
 		for i in range(0, 5):
-			lv_name = rs(8, '_lv')
+			lv_name = lv_n()
 
 			thin_lv_path = self.handle_return(
 				thin_pool.ThinPool.LvCreate(
@@ -365,8 +396,9 @@ class TestDbusService(unittest.TestCase):
 			full_name = "%s/%s" % (vg_name_start, lv_name)
 
 			lookup_lv_path = mgr.LookUpByLvmId(full_name)
-			self.assertTrue(thin_lv_path == lookup_lv_path,
-							"%s != %s" % (thin_lv_path, lookup_lv_path))
+			self.assertTrue(
+				thin_lv_path == lookup_lv_path,
+				"%s != %s" % (thin_lv_path, lookup_lv_path))
 
 		# Rename the VG
 		new_name = 'renamed_' + vg.Name
@@ -384,13 +416,15 @@ class TestDbusService(unittest.TestCase):
 
 		for l in lv_paths:
 			lv_proxy = ClientProxy(self.bus, l).LvCommon
-			self.assertTrue(lv_proxy.Vg == vg.object_path, "%s != %s" %
-							(lv_proxy.Vg, vg.object_path))
+			self.assertTrue(
+				lv_proxy.Vg == vg.object_path, "%s != %s" %
+				(lv_proxy.Vg, vg.object_path))
 			full_name = "%s/%s" % (new_name, lv_proxy.Name)
 			# print('Full Name %s' % (full_name))
 			lv_path = mgr.LookUpByLvmId(full_name)
-			self.assertTrue(lv_path == lv_proxy.object_path, "%s != %s" %
-							(lv_path, lv_proxy.object_path))
+			self.assertTrue(
+				lv_path == lv_proxy.object_path, "%s != %s" %
+				(lv_path, lv_proxy.object_path))
 
 		# noinspection PyTypeChecker
 		self._verify_hidden_lookups(thin_pool.LvCommon, new_name)
@@ -416,14 +450,14 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		self._test_lv_create(
 			vg.LvCreate,
-			(rs(8, '_lv'), mib(4),
-			 dbus.Array([], '(ott)'), g_tmo, {}), vg)
+			(lv_n(), mib(4),
+				dbus.Array([], '(ott)'), g_tmo, {}), vg)
 
 	def test_lv_create_job(self):
 
 		vg = self._vg_create().Vg
-		(object_path, job_path) = vg.LvCreate(rs(8, '_lv'), mib(4),
-			dbus.Array([], '(ott)'), 0, {})
+		(object_path, job_path) = vg.LvCreate(
+			lv_n(), mib(4), dbus.Array([], '(ott)'), 0, {})
 
 		self.assertTrue(object_path == '/')
 		self.assertTrue(job_path != '/')
@@ -435,7 +469,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), mib(4), False, g_tmo, {}), vg)
+			(lv_n(), mib(4), False, g_tmo, {}), vg)
 
 	def test_lv_create_striped(self):
 		pv_paths = []
@@ -444,9 +478,7 @@ class TestDbusService(unittest.TestCase):
 
 		vg = self._vg_create(pv_paths).Vg
 		self._test_lv_create(
-			vg.LvCreateStriped,
-			(rs(8, '_lv'), mib(4), 2, 8, False,
-			 g_tmo, {}), vg)
+			vg.LvCreateStriped, (lv_n(), mib(4), 2, 8, False, g_tmo, {}), vg)
 
 	def test_lv_create_mirror(self):
 		pv_paths = []
@@ -454,8 +486,8 @@ class TestDbusService(unittest.TestCase):
 			pv_paths.append(pp.object_path)
 
 		vg = self._vg_create(pv_paths).Vg
-		self._test_lv_create(vg.LvCreateMirror,
-							 (rs(8, '_lv'), mib(4), 2, g_tmo, {}), vg)
+		self._test_lv_create(
+			vg.LvCreateMirror, (lv_n(), mib(4), 2, g_tmo, {}), vg)
 
 	def test_lv_create_raid(self):
 		pv_paths = []
@@ -463,9 +495,8 @@ class TestDbusService(unittest.TestCase):
 			pv_paths.append(pp.object_path)
 
 		vg = self._vg_create(pv_paths).Vg
-		self._test_lv_create(vg.LvCreateRaid,
-							 (rs(8, '_lv'), 'raid4',
-							  mib(16), 2, 8, g_tmo, {}), vg)
+		self._test_lv_create(
+			vg.LvCreateRaid, (lv_n(), 'raid4', mib(16), 2, 8, g_tmo, {}), vg)
 
 	def _create_lv(self, thinpool=False, size=None, vg=None):
 
@@ -481,7 +512,7 @@ class TestDbusService(unittest.TestCase):
 
 		return self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), size, thinpool, g_tmo, {}), vg)
+			(lv_n(), size, thinpool, g_tmo, {}), vg)
 
 	def test_lv_create_rounding(self):
 		self._create_lv(size=(mib(2) + 13))
@@ -508,8 +539,9 @@ class TestDbusService(unittest.TestCase):
 	def test_lv_thinpool_rename(self):
 		# Rename a thin pool
 		tp = self._create_lv(True)
-		self.assertTrue(THINPOOL_LV_PATH in tp.object_path,
-						"%s" % (tp.object_path))
+		self.assertTrue(
+			THINPOOL_LV_PATH in tp.object_path,
+			"%s" % (tp.object_path))
 
 		new_name = 'renamed_' + tp.LvCommon.Name
 		self.handle_return(tp.Lv.Rename(new_name, g_tmo, {}))
@@ -527,7 +559,7 @@ class TestDbusService(unittest.TestCase):
 
 		thin_path = self.handle_return(
 			tp.ThinPool.LvCreate(
-				rs(10, '_thin_lv'), mib(8), g_tmo, {})
+				lv_n('_thin_lv'), mib(8), g_tmo, {})
 		)
 
 		lv = ClientProxy(self.bus, thin_path)
@@ -585,11 +617,13 @@ class TestDbusService(unittest.TestCase):
 
 		pv = vg.Pvs
 
-		pv_proxy = ClientProxy(self.bus, pv[0])
+		pvp = ClientProxy(self.bus, pv[0])
 
-		self._test_lv_create(vg.LvCreate, (rs(8, '_lv'), mib(4),
-										   dbus.Array([[pv_proxy.object_path, 0, (pv_proxy.Pv.PeCount - 1)]],
-			'(ott)'), g_tmo, {}), vg)
+		self._test_lv_create(
+			vg.LvCreate,
+			(lv_n(), mib(4),
+				dbus.Array([[pvp.object_path, 0, (pvp.Pv.PeCount - 1)]],
+				'(ott)'), g_tmo, {}), vg)
 
 	def test_lv_resize(self):
 
@@ -619,8 +653,8 @@ class TestDbusService(unittest.TestCase):
 				rc = self.handle_return(
 					lv.Lv.Resize(
 						size,
-						dbus.Array([[p.object_path, 0, p.Pv.PeCount - 1]],
-								   '(oii)'),
+						dbus.Array(
+							[[p.object_path, 0, p.Pv.PeCount - 1]], '(oii)'),
 						g_tmo, {}))
 			else:
 				rc = self.handle_return(
@@ -647,8 +681,8 @@ class TestDbusService(unittest.TestCase):
 		lv = self._create_lv(vg=vg)
 
 		with self.assertRaises(dbus.exceptions.DBusException):
-				lv.Lv.Resize(lv.LvCommon.SizeBytes, dbus.Array([], '(oii)'),
-							 -1, {})
+				lv.Lv.Resize(
+					lv.LvCommon.SizeBytes, dbus.Array([], '(oii)'), -1, {})
 
 	def test_lv_move(self):
 		lv = self._create_lv()
@@ -666,8 +700,8 @@ class TestDbusService(unittest.TestCase):
 
 		lv.update()
 		new_pv = str(lv.LvCommon.Devices[0][0])
-		self.assertTrue(pv_path_move != new_pv, "%s == %s" %
-						(pv_path_move, new_pv))
+		self.assertTrue(
+			pv_path_move != new_pv, "%s == %s" % (pv_path_move, new_pv))
 
 	def test_lv_activate_deactivate(self):
 		lv_p = self._create_lv()
@@ -732,7 +766,7 @@ class TestDbusService(unittest.TestCase):
 		for pp in self.objs[PV_INT]:
 			pv_paths.append(pp.object_path)
 
-		vg_name = rs(8, '_vg')
+		vg_name = vg_n()
 
 		# Test getting a job right away
 		vg_path, vg_job = self.objs[MANAGER_INT][0].Manager.VgCreate(
@@ -762,7 +796,7 @@ class TestDbusService(unittest.TestCase):
 			if vg_proxy.Vg.FreeCount > 0:
 				job = self.handle_return(
 					vg_proxy.Vg.LvCreateLinear(
-						rs(8, "_lv"), mib(4), False, g_tmo, {}))
+						lv_n(), mib(4), False, g_tmo, {}))
 				self.assertTrue(job != '/')
 			else:
 				# We ran out of space, test will probably fail
@@ -795,12 +829,17 @@ class TestDbusService(unittest.TestCase):
 
 		yes = False
 
+		for pp in self.objs[PV_INT]:
+			if '/dev/sd' not in pp.Pv.Name:
+				std_err_print("Skipping test_job_handling_timer on loopback")
+				return
+
 		# This may not pass
 		for i in [48, 64, 128]:
 			yes = self._test_expired_timer(i)
 			if yes:
 				break
-			print('Attempt (%d) failed, trying again...' % (i))
+			std_err_print('Attempt (%d) failed, trying again...' % (i))
 
 		self.assertTrue(yes)
 
@@ -853,7 +892,7 @@ class TestDbusService(unittest.TestCase):
 		vg = self._vg_create().Vg
 		lv = self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), mib(4), False, g_tmo, {}),
+			(lv_n(), mib(4), False, g_tmo, {}),
 			vg)
 
 		t = ['Testing', 'tags']
@@ -891,8 +930,9 @@ class TestDbusService(unittest.TestCase):
 				vg.MaxPvSet(p, g_tmo, {}))
 			self.assertEqual(rc, '/')
 			vg.update()
-			self.assertTrue(vg.MaxPv == p, "Expected %s != Actual %s" %
-							(str(p), str(vg.MaxPv)))
+			self.assertTrue(
+				vg.MaxPv == p,
+				"Expected %s != Actual %s" % (str(p), str(vg.MaxPv)))
 
 	def test_vg_max_lv(self):
 		vg = self._vg_create().Vg
@@ -903,14 +943,15 @@ class TestDbusService(unittest.TestCase):
 			rc = self.handle_return(vg.MaxLvSet(p, g_tmo, {}))
 			self.assertEqual(rc, '/')
 			vg.update()
-			self.assertTrue(vg.MaxLv == p, "Expected %s != Actual %s" %
-							(str(p), str(vg.MaxLv)))
+			self.assertTrue(
+				vg.MaxLv == p,
+				"Expected %s != Actual %s" % (str(p), str(vg.MaxLv)))
 
 	def test_vg_uuid_gen(self):
 		# TODO renable test case when
 		# https://bugzilla.redhat.com/show_bug.cgi?id=1264169 gets fixed
 		# This was tested with lvmetad disabled and we passed
-		print("\nSkipping Vg.UuidGenerate until BZ: 1264169 resolved\n")
+		std_err_print("\nSkipping Vg.UuidGenerate until BZ: 1264169 resolved\n")
 
 		if False:
 			vg = self._vg_create().Vg
@@ -918,14 +959,15 @@ class TestDbusService(unittest.TestCase):
 			rc = self.handle_return(vg.UuidGenerate(g_tmo, {}))
 			self.assertEqual(rc, '/')
 			vg.update()
-			self.assertTrue(vg.Uuid != prev_uuid, "Expected %s != Actual %s" %
-							(vg.Uuid, prev_uuid))
+			self.assertTrue(
+				vg.Uuid != prev_uuid,
+				"Expected %s != Actual %s" % (vg.Uuid, prev_uuid))
 
 	def test_vg_activate_deactivate(self):
 		vg = self._vg_create().Vg
 		self._test_lv_create(
 			vg.LvCreateLinear,
-			(rs(8, '_lv'), mib(4), False, g_tmo, {}),
+			(lv_n(), mib(4), False, g_tmo, {}),
 			vg)
 
 		vg.update()
@@ -1000,8 +1042,9 @@ class TestDbusService(unittest.TestCase):
 
 		self.assertEqual(
 			self.handle_return(
-				mgr.PvScan(False, True, dbus.Array([], 's'),
-						   dbus.Array([], '(ii)'), g_tmo, {})), '/')
+				mgr.PvScan(
+					False, True, dbus.Array([], 's'),
+					dbus.Array([], '(ii)'), g_tmo, {})), '/')
 
 		self.assertEqual(self._refresh(), 0)
 		self.assertEqual(
@@ -1031,13 +1074,8 @@ class TestDbusService(unittest.TestCase):
 			mm.append((int(d.properties['MAJOR']), int(d.properties['MINOR'])))
 
 		self.assertEqual(
-
 			self.handle_return(
-				mgr.PvScan
-				(False, True,
-				 block_path,
-				 mm, g_tmo, {})
-			), '/')
+				mgr.PvScan(False, True, block_path, mm, g_tmo, {})), '/')
 
 		self.assertEqual(self._refresh(), 0)
 
@@ -1084,7 +1122,7 @@ class TestDbusService(unittest.TestCase):
 
 		thin_path = self.handle_return(
 			tp.ThinPool.LvCreate(
-				rs(10, '_thin_lv'), mib(10), g_tmo, {}))
+				lv_n('_thin_lv'), mib(10), g_tmo, {}))
 
 		lv_p = ClientProxy(self.bus, thin_path)
 
@@ -1118,8 +1156,8 @@ class TestDbusService(unittest.TestCase):
 
 		vg, cache_pool = self._create_cache_pool()
 
-		self.assertTrue('/com/redhat/lvmdbus1/CachePool' in
-						cache_pool.object_path)
+		self.assertTrue(
+			'/com/redhat/lvmdbus1/CachePool' in cache_pool.object_path)
 
 	def test_cache_lv_create(self):
 
@@ -1135,11 +1173,10 @@ class TestDbusService(unittest.TestCase):
 			cached_lv = ClientProxy(self.bus, c_lv_path)
 
 			uncached_lv_path = self.handle_return(
-				cached_lv.CachedLv.DetachCachePool(
-					destroy_cache, g_tmo, {}))
+				cached_lv.CachedLv.DetachCachePool(destroy_cache, g_tmo, {}))
 
-			self.assertTrue('/com/redhat/lvmdbus1/Lv' in
-							uncached_lv_path)
+			self.assertTrue(
+				'/com/redhat/lvmdbus1/Lv' in uncached_lv_path)
 
 			rc = self.handle_return(vg.Remove(g_tmo, {}))
 			self.assertTrue(rc == '/')
@@ -1201,22 +1238,24 @@ class TestDbusService(unittest.TestCase):
 			with self.assertRaises(dbus.exceptions.DBusException):
 				self.handle_return(
 					vg_proxy.Vg.LvCreateLinear(
-						rs(8, '_lv') + c,
+						lv_n() + c,
 						mib(4), False, g_tmo, {}))
 
-		for r in ("_cdata", "_cmeta", "_corig", "_mimage", "_mlog",
-			"_pmspare", "_rimage", "_rmeta", "_tdata", "_tmeta", "_vorigin"):
+		for reserved in (
+				"_cdata", "_cmeta", "_corig", "_mimage", "_mlog",
+				"_pmspare", "_rimage", "_rmeta", "_tdata", "_tmeta",
+				"_vorigin"):
 			with self.assertRaises(dbus.exceptions.DBusException):
 				self.handle_return(
 					vg_proxy.Vg.LvCreateLinear(
-						rs(8, '_lv') + r,
+						lv_n() + reserved,
 						mib(4), False, g_tmo, {}))
 
-		for r in ("snapshot", "pvmove"):
+		for reserved in ("snapshot", "pvmove"):
 			with self.assertRaises(dbus.exceptions.DBusException):
 				self.handle_return(
 					vg_proxy.Vg.LvCreateLinear(
-						r + rs(8, '_lv'),
+						reserved + lv_n(),
 						mib(4), False, g_tmo, {}))
 
 	_ALLOWABLE_TAG_CH = string.ascii_letters + string.digits + "._-+/=!:&#"
@@ -1256,16 +1295,18 @@ class TestDbusService(unittest.TestCase):
 		for i in range(1, 64):
 			tag = rs(i, "", self._ALLOWABLE_TAG_CH)
 
-			r = self.handle_return(
+			tmp = self.handle_return(
 				vg_proxy.Vg.TagsAdd([tag], g_tmo, {}))
-			self.assertTrue(r == '/')
+			self.assertTrue(tmp == '/')
 			vg_proxy.update()
 
-			self.assertTrue(tag in vg_proxy.Vg.Tags, "%s not in %s" %
-				(tag, str(vg_proxy.Vg.Tags)))
+			self.assertTrue(
+				tag in vg_proxy.Vg.Tags,
+				"%s not in %s" % (tag, str(vg_proxy.Vg.Tags)))
 
-			self.assertEqual(i, len(vg_proxy.Vg.Tags), "%d != %d" %
-				(i, len(vg_proxy.Vg.Tags)))
+			self.assertEqual(
+				i, len(vg_proxy.Vg.Tags),
+				"%d != %d" % (i, len(vg_proxy.Vg.Tags)))
 
 	def test_tag_regression(self):
 		mgr = self.objs[MANAGER_INT][0].Manager
@@ -1277,37 +1318,64 @@ class TestDbusService(unittest.TestCase):
 
 		tag = '--h/K.6g0A4FOEatf3+k_nI/Yp&L_u2oy-=j649x:+dUcYWPEo6.IWT0c'
 
-		r = self.handle_return(
+		tmp = self.handle_return(
 			vg_proxy.Vg.TagsAdd([tag], g_tmo, {})
 		)
-		self.assertTrue(r == '/')
+		self.assertTrue(tmp == '/')
 		vg_proxy.update()
 
-		self.assertTrue(tag in vg_proxy.Vg.Tags, "%s not in %s" %
-						(tag, str(vg_proxy.Vg.Tags)))
+		self.assertTrue(
+			tag in vg_proxy.Vg.Tags,
+			"%s not in %s" % (tag, str(vg_proxy.Vg.Tags)))
+
+
+class AggregateResults(object):
+
+	def __init__(self):
+		self.no_errors = True
+
+	def register_result(self, result):
+		if not result.result.wasSuccessful():
+			self.no_errors = False
+
+	def register_fail(self):
+		self.no_errors = False
+
+	def exit_run(self):
+		if self.no_errors:
+			sys.exit(0)
+		sys.exit(1)
 
 
 if __name__ == '__main__':
+
+	r = AggregateResults()
+
 	# Test forking & exec new each time
 	test_shell = os.getenv('LVM_DBUS_TEST_SHELL', 1)
 
 	# Default to no lvm shell
 	set_execution(False)
 
-	if test_shell == 0:
-		unittest.main(exit=True)
+	if int(test_shell) == 0:
+		std_err_print('\n Running only lvm fork & exec test ***\n')
+		r.register_result(unittest.main(exit=False))
 	else:
-		print('\n *** Testing fork & exec *** \n')
-		unittest.main(exit=False)
+		std_err_print('\n *** Testing with lvm fork & exec *** \n')
+		r.register_result(unittest.main(exit=False))
 		g_tmo = 15
-		unittest.main(exit=False)
+		r.register_result(unittest.main(exit=False))
 		# Test lvm shell
-		print('\n *** Testing lvm shell *** \n')
+		std_err_print('\n *** Testing with lvm shell *** \n')
 		if set_execution(True):
 			g_tmo = 0
-			unittest.main(exit=False)
+			r.register_result(unittest.main(exit=False))
 			g_tmo = 15
-			unittest.main()
+			r.register_result(unittest.main(exit=False))
 		else:
-			print("WARNING: Unable to dynamically configure "
-				"service to use lvm shell!")
+			r.register_fail()
+			std_err_print(
+				"ERROR: Unable to dynamically configure service to use "
+				"lvm shell!")
+
+	r.exit_run()
