@@ -73,6 +73,7 @@ xx(devtypes,
    "\t[--nosuffix]\n"
    "\t[-o|--options [+|-|#]Field[,Field]]\n"
    "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--rows]\n"
    "\t[-S|--select Selection]\n"
    "\t[--separator Separator]\n"
@@ -80,10 +81,9 @@ xx(devtypes,
    "\t[--unquoted]\n"
    "\t[--version]\n",
 
-   aligned_ARG, binary_ARG, nameprefixes_ARG,
-   noheadings_ARG, nosuffix_ARG, options_ARG,
-   rows_ARG, select_ARG, separator_ARG, sort_ARG,
-   unbuffered_ARG, unquoted_ARG)
+   aligned_ARG, binary_ARG, nameprefixes_ARG, noheadings_ARG,
+   nosuffix_ARG, options_ARG, reportformat_ARG, rows_ARG,
+   select_ARG, separator_ARG, sort_ARG, unbuffered_ARG, unquoted_ARG)
 
 xx(dumpconfig,
    "Display and manipulate configuration information",
@@ -136,6 +136,56 @@ xx(lvactivate,
    "Logical Volume(s)\n")
 ***********/
 
+xx(fullreport,
+   "Display full report",
+   PERMITTED_READ_ONLY | ALL_VGS_IS_DEFAULT | LOCKD_VG_SH,
+   "fullreport\n"
+   "\t[--aligned]\n"
+   "\t[--binary]\n"
+   "\t[-a|--all]\n"
+   "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
+   "\t[-d|--debug]\n"
+   "\t[--foreign]\n"
+   "\t[-h|--help]\n"
+   "\t[--ignorelockingfailure]\n"
+   "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
+   "\t[--nameprefixes]\n"
+   "\t[--noheadings]\n"
+   "\t[--nosuffix]\n"
+   "\t[-o|--options [+|-|#]Field[,Field]]\n"
+   "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
+   "\t[-P|--partial]\n"
+   "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
+   "\t[--rows]\n"
+   "\t[-S|--select Selection]\n"
+   "\t[--separator Separator]\n"
+   "\t[--trustcache]\n"
+   "\t[--unbuffered]\n"
+   "\t[--units hHbBsSkKmMgGtTpPeE]\n"
+   "\t[--unquoted]\n"
+   "\t[-v|--verbose]\n"
+   "\t[--version]\n"
+   "\t[VolumeGroupName [VolumeGroupName...]]\n",
+
+   aligned_ARG, all_ARG, binary_ARG, configreport_ARG, foreign_ARG,
+   ignorelockingfailure_ARG, ignoreskippedcluster_ARG, logonly_ARG,
+   nameprefixes_ARG, noheadings_ARG, nolocking_ARG, nosuffix_ARG,
+   options_ARG, partial_ARG, readonly_ARG, reportformat_ARG, rows_ARG,
+   select_ARG, separator_ARG, shared_ARG, sort_ARG, trustcache_ARG,
+   unbuffered_ARG, units_ARG, unquoted_ARG)
+
+xx(lastlog,
+   "Display last command's log report",
+   PERMITTED_READ_ONLY | NO_METADATA_PROCESSING,
+   "log\n"
+   "\t[--reportformat {basic|json}]\n"
+   "\t[-S|--select Selection]\n",
+
+   reportformat_ARG, select_ARG)
+
 xx(lvchange,
    "Change the attributes of logical volume(s)",
    CACHE_VGMETADATA | PERMITTED_READ_ONLY,
@@ -145,6 +195,7 @@ xx(lvchange,
    "\t[--activationmode {complete|degraded|partial}"
    "\t[--addtag <Tag>]\n"
    "\t[--alloc <AllocationPolicy>]\n"
+   "\t[--rebuild PhysicalVolume]\n"
    "\t[-C|--contiguous {y|n}]\n"
    "\t[--cachemode <CacheMode>]\n"
    "\t[--cachepolicy <policyname>] [--cachesettings <parameter=value>]\n"
@@ -175,6 +226,7 @@ xx(lvchange,
    "\t[--[raid]writemostly <PhysicalVolume>[:{t|n|y}]]\n"
    "\t[-r|--readahead <ReadAheadSectors>|auto|none]\n"
    "\t[--refresh]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--resync]\n"
    "\t[-S|--select Selection]\n"
    "\t[--sysinit]\n"
@@ -193,10 +245,10 @@ xx(lvchange,
    ignoreskippedcluster_ARG, major_ARG, metadataprofile_ARG, minor_ARG,
    monitor_ARG, minrecoveryrate_ARG, maxrecoveryrate_ARG, noudevsync_ARG,
    partial_ARG, permission_ARG, persistent_ARG, poll_ARG,
-   raidminrecoveryrate_ARG, raidmaxrecoveryrate_ARG, raidsyncaction_ARG,
-   raidwritebehind_ARG, raidwritemostly_ARG, readahead_ARG, resync_ARG,
-   refresh_ARG, select_ARG, setactivationskip_ARG, syncaction_ARG, sysinit_ARG,
-   test_ARG, writebehind_ARG, writemostly_ARG, zero_ARG)
+   raidrebuild_ARG, raidminrecoveryrate_ARG, raidmaxrecoveryrate_ARG,
+   raidsyncaction_ARG, raidwritebehind_ARG, raidwritemostly_ARG, readahead_ARG,
+   reportformat_ARG, rebuild_ARG, resync_ARG, refresh_ARG, select_ARG, setactivationskip_ARG,
+   syncaction_ARG, sysinit_ARG, test_ARG, writebehind_ARG, writemostly_ARG, zero_ARG)
 
 #define COMMON_OPTS \
 	"\t[--commandprofile <ProfileName>] [-d|--debug] [-h|-?|--help]\n" \
@@ -208,6 +260,7 @@ xx(lvconvert,
    "lvconvert "
    "[-m|--mirrors <Mirrors> [--mirrorlog {disk|core|mirrored}|--corelog]]\n"
    "\t[--type <SegmentType>]\n"
+   "\t[--rebuild PhysicalVolume]\n"
    "\t[--repair [--use-policies]]\n"
    "\t[--replace PhysicalVolume]\n"
    "\t[-R|--regionsize <MirrorLogRegionSize>]\n"
@@ -337,6 +390,7 @@ xx(lvcreate,
    "\t[--[raid]minrecoveryrate Rate]\n"
    "\t[--[raid]maxrecoveryrate Rate]\n"
    "\t[-r|--readahead {ReadAheadSectors|auto|none}]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-R|--regionsize MirrorLogRegionSize]\n"
    "\t[-T|--thin\n"
    "\t  [--discards {ignore|nopassdown|passdown}]\n"
@@ -380,6 +434,7 @@ xx(lvcreate,
    "\t[--noudevsync]\n"
    "\t[-p|--permission {r|rw}]\n"
    "\t[-r|--readahead ReadAheadSectors|auto|none]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[{--thinpool ThinPoolLogicalVolume[Path] |\n"
    "\t  --cachepool CachePoolLogicalVolume[Path]}]\n"
@@ -397,9 +452,10 @@ xx(lvcreate,
    //pooldatasize_ARG,
    poolmetadatasize_ARG, poolmetadataspare_ARG,
    raidminrecoveryrate_ARG, raidmaxrecoveryrate_ARG,
-   readahead_ARG, regionsize_ARG, setactivationskip_ARG, size_ARG, snapshot_ARG,
-   stripes_ARG, stripesize_ARG, test_ARG, thin_ARG, thinpool_ARG, type_ARG,
-   virtualoriginsize_ARG, virtualsize_ARG, wipesignatures_ARG, zero_ARG)
+   readahead_ARG, regionsize_ARG, reportformat_ARG, setactivationskip_ARG,
+   size_ARG, snapshot_ARG, stripes_ARG, stripesize_ARG, test_ARG, thin_ARG,
+   thinpool_ARG, type_ARG, virtualoriginsize_ARG, virtualsize_ARG,
+   wipesignatures_ARG, zero_ARG)
 
 xx(lvdisplay,
    "Display information about a logical volume",
@@ -418,6 +474,7 @@ xx(lvdisplay,
    "\t[--nosuffix]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[--units hHbBsSkKmMgGtTpPeE]\n"
    "\t[-v|--verbose]\n"
@@ -429,12 +486,14 @@ xx(lvdisplay,
    "\t[-a|--all]\n"
    "\t[--binary]\n"
    "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
    "\t[-d|--debug]\n"
    "\t[--foreign]\n"
    "\t[-h|--help]\n"
    "\t[-H|--history]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
    "\t[--noheadings]\n"
    "\t[--nosuffix]\n"
    "\t[-o|--options [+|-|#]Field[,Field]]\n"
@@ -442,6 +501,7 @@ xx(lvdisplay,
    "\t[-S|--select Selection]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--segments]\n"
    "\t[--separator Separator]\n"
    "\t[--unbuffered]\n"
@@ -450,10 +510,11 @@ xx(lvdisplay,
    "\t[--version]\n"
    "\t[LogicalVolume[Path] [LogicalVolume[Path]...]]\n",
 
-    aligned_ARG, all_ARG, binary_ARG, colon_ARG, columns_ARG, foreign_ARG,
-    history_ARG, ignorelockingfailure_ARG, ignoreskippedcluster_ARG,
-    maps_ARG, noheadings_ARG, nosuffix_ARG, options_ARG, sort_ARG,
-    partial_ARG, readonly_ARG, segments_ARG, select_ARG, separator_ARG,
+    aligned_ARG, all_ARG, binary_ARG, colon_ARG, columns_ARG,
+    configreport_ARG, foreign_ARG, history_ARG, ignorelockingfailure_ARG,
+    ignoreskippedcluster_ARG, logonly_ARG, maps_ARG, noheadings_ARG,
+    nosuffix_ARG, options_ARG, sort_ARG, partial_ARG, readonly_ARG,
+    reportformat_ARG, segments_ARG, select_ARG, separator_ARG,
     shared_ARG, unbuffered_ARG, units_ARG)
 
 xx(lvextend,
@@ -475,6 +536,7 @@ xx(lvextend,
    "\t[--use-policies]\n"
    "\t[-n|--nofsck]\n"
    "\t[--noudevsync]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-r|--resizefs]\n"
    "\t[-t|--test]\n"
    "\t[--type VolumeType]\n"
@@ -484,7 +546,7 @@ xx(lvextend,
 
    alloc_ARG, autobackup_ARG, extents_ARG, force_ARG, mirrors_ARG,
    nofsck_ARG, nosync_ARG, noudevsync_ARG, poolmetadatasize_ARG,
-   resizefs_ARG, size_ARG, stripes_ARG, stripesize_ARG,
+   reportformat_ARG, resizefs_ARG, size_ARG, stripes_ARG, stripesize_ARG,
    test_ARG, type_ARG, usepolicies_ARG)
 
 xx(lvmchange,
@@ -584,6 +646,7 @@ xx(lvreduce,
    "\t[-n|--nofsck]\n"
    "\t[--noudevsync]\n"
    "\t[-r|--resizefs]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
@@ -591,7 +654,7 @@ xx(lvreduce,
    "\tLogicalVolume[Path]\n",
 
    autobackup_ARG, force_ARG,  extents_ARG, nofsck_ARG, noudevsync_ARG,
-   resizefs_ARG, size_ARG, test_ARG)
+   reportformat_ARG, resizefs_ARG, size_ARG, test_ARG)
 
 xx(lvremove,
    "Remove logical volume(s) from the system",
@@ -604,6 +667,7 @@ xx(lvremove,
    "\t[-h|--help]\n"
    "\t[--nohistory]\n"
    "\t[--noudevsync]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
@@ -611,7 +675,7 @@ xx(lvremove,
    "\tLogicalVolume[Path] [LogicalVolume[Path]...]\n",
 
    autobackup_ARG, force_ARG, nohistory_ARG, noudevsync_ARG,
-   select_ARG, test_ARG)
+   reportformat_ARG, select_ARG, test_ARG)
 
 xx(lvrename,
    "Rename a logical volume",
@@ -622,13 +686,14 @@ xx(lvrename,
    "\t[-d|--debug]\n"
    "\t[-h|-?|--help]\n"
    "\t[--noudevsync]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\t{ OldLogicalVolumePath NewLogicalVolumePath |\n"
    "\t  VolumeGroupName OldLogicalVolumeName NewLogicalVolumeName }\n",
 
-   autobackup_ARG, noudevsync_ARG, test_ARG)
+   autobackup_ARG, noudevsync_ARG, reportformat_ARG, test_ARG)
 
 xx(lvresize,
    "Resize a logical volume",
@@ -646,6 +711,7 @@ xx(lvresize,
    "\t --poolmetadatasize [+]MetadataVolumeSize[bBsSkKmMgG]}\n"
    "\t[-n|--nofsck]\n"
    "\t[--noudevsync]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-r|--resizefs]\n"
    "\t[-t|--test]\n"
    "\t[--type VolumeType]\n"
@@ -654,8 +720,8 @@ xx(lvresize,
    "\tLogicalVolume[Path] [ PhysicalVolumePath... ]\n",
 
    alloc_ARG, autobackup_ARG, extents_ARG, force_ARG, nofsck_ARG,
-   noudevsync_ARG, resizefs_ARG, poolmetadatasize_ARG,
-   size_ARG, stripes_ARG, stripesize_ARG,
+   noudevsync_ARG, reportformat_ARG, resizefs_ARG,
+   poolmetadatasize_ARG, size_ARG, stripes_ARG, stripesize_ARG,
    test_ARG, type_ARG)
 
 xx(lvs,
@@ -666,12 +732,14 @@ xx(lvs,
    "\t[--aligned]\n"
    "\t[--binary]\n"
    "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
    "\t[-d|--debug]\n"
    "\t[--foreign]\n"
    "\t[-h|--help]\n"
    "\t[-H|--history]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
    "\t[--nameprefixes]\n"
    "\t[--noheadings]\n"
    "\t[--nosuffix]\n"
@@ -679,6 +747,7 @@ xx(lvs,
    "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--rows]\n"
    "\t[--segments]\n"
    "\t[-S|--select Selection]\n"
@@ -691,12 +760,12 @@ xx(lvs,
    "\t[--version]\n"
    "\t[LogicalVolume[Path] [LogicalVolume[Path]...]]\n",
 
-   aligned_ARG, all_ARG, binary_ARG, foreign_ARG, history_ARG,
-   ignorelockingfailure_ARG, ignoreskippedcluster_ARG, nameprefixes_ARG,
-   noheadings_ARG, nolocking_ARG, nosuffix_ARG, options_ARG, partial_ARG,
-   readonly_ARG, rows_ARG, segments_ARG, select_ARG, separator_ARG,
-   shared_ARG, sort_ARG, trustcache_ARG, unbuffered_ARG, units_ARG,
-   unquoted_ARG)
+   aligned_ARG, all_ARG, binary_ARG, configreport_ARG, foreign_ARG, history_ARG,
+   ignorelockingfailure_ARG, ignoreskippedcluster_ARG, logonly_ARG,
+   nameprefixes_ARG, noheadings_ARG, nolocking_ARG, nosuffix_ARG,
+   options_ARG, partial_ARG, readonly_ARG, reportformat_ARG, rows_ARG,
+   segments_ARG, select_ARG, separator_ARG, shared_ARG, sort_ARG,
+   trustcache_ARG, unbuffered_ARG, units_ARG, unquoted_ARG)
 
 xx(lvscan,
    "List all logical volumes in all volume groups",
@@ -711,11 +780,12 @@ xx(lvscan,
    "\t[--ignorelockingfailure]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n",
 
    all_ARG, blockdevice_ARG, ignorelockingfailure_ARG, partial_ARG,
-   readonly_ARG, cache_long_ARG)
+   readonly_ARG, reportformat_ARG, cache_long_ARG)
 
 xx(pvchange,
    "Change attributes of physical volume(s)",
@@ -729,6 +799,7 @@ xx(pvchange,
    "\t[-h|--help]\n"
    "\t[--ignoreskippedcluster]\n"
    "\t[--metadataignore y|n]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[-t|--test]\n"
    "\t[-u|--uuid]\n"
@@ -741,7 +812,7 @@ xx(pvchange,
 
    all_ARG, allocatable_ARG, allocation_ARG, autobackup_ARG, deltag_ARG,
    addtag_ARG, force_ARG, ignoreskippedcluster_ARG, metadataignore_ARG,
-   select_ARG, test_ARG, uuid_ARG)
+   reportformat_ARG, select_ARG, test_ARG, uuid_ARG)
 
 xx(pvresize,
    "Resize physical volume(s)",
@@ -750,13 +821,14 @@ xx(pvresize,
    "\t[--commandprofile ProfileName]\n"
    "\t[-d|--debug]\n"
    "\t[-h|-?|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--setphysicalvolumesize PhysicalVolumeSize[bBsSkKmMgGtTpPeE]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\tPhysicalVolume [PhysicalVolume...]\n",
 
-   physicalvolumesize_ARG, test_ARG)
+   physicalvolumesize_ARG, reportformat_ARG, test_ARG)
 
 xx(pvck,
    "Check the consistency of physical volume(s)",
@@ -778,6 +850,7 @@ xx(pvcreate,
    "pvcreate\n"
    "\t[--norestorefile]\n"
    "\t[--restorefile file]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--commandprofile ProfileName]\n"
    "\t[-d|--debug]\n"
    "\t[-f[f]|--force [--force]]\n"
@@ -802,7 +875,7 @@ xx(pvcreate,
    force_ARG, test_ARG, labelsector_ARG, metadatatype_ARG,
    metadatacopies_ARG, metadatasize_ARG, metadataignore_ARG,
    norestorefile_ARG, physicalvolumesize_ARG, pvmetadatacopies_ARG,
-   restorefile_ARG, uuidstr_ARG, zero_ARG)
+   reportformat_ARG, restorefile_ARG, uuidstr_ARG, zero_ARG)
 
 xx(pvdata,
    "Display the on-disk metadata for physical volume(s)",
@@ -838,6 +911,7 @@ xx(pvdisplay,
    "\t[-m|--maps]\n"
    "\t[--nosuffix]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[-s|--short]\n"
    "\t[--units hHbBsSkKmMgGtTpPeE]\n"
@@ -850,15 +924,18 @@ xx(pvdisplay,
    "\t[-a|--all]\n"
    "\t[--binary]\n"
    "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
    "\t[-d|--debug]\n"
    "\t[--foreign]\n"
    "\t[-h|--help]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
    "\t[--noheadings]\n"
    "\t[--nosuffix]\n"
    "\t[-o|--options [+|-|#]Field[,Field]]\n"
    "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[--readonly]\n"
    "\t[--separator Separator]\n"
@@ -868,11 +945,11 @@ xx(pvdisplay,
    "\t[--version]\n"
    "\t[PhysicalVolumePath [PhysicalVolumePath...]]\n",
 
-   aligned_ARG, all_ARG, binary_ARG, colon_ARG, columns_ARG, foreign_ARG,
-   ignorelockingfailure_ARG, ignoreskippedcluster_ARG, maps_ARG,
-   noheadings_ARG, nosuffix_ARG, options_ARG, readonly_ARG,
-   select_ARG, separator_ARG, shared_ARG, short_ARG, sort_ARG, unbuffered_ARG,
-   units_ARG)
+   aligned_ARG, all_ARG, binary_ARG, colon_ARG, columns_ARG, configreport_ARG,
+   foreign_ARG, ignorelockingfailure_ARG, ignoreskippedcluster_ARG,
+   logonly_ARG, maps_ARG, noheadings_ARG, nosuffix_ARG, options_ARG,
+   readonly_ARG, reportformat_ARG, select_ARG, separator_ARG, shared_ARG,
+   short_ARG, sort_ARG, unbuffered_ARG, units_ARG)
 
 /* ALL_VGS_IS_DEFAULT is for polldaemon to find pvmoves in-progress using process_each_vg. */
 
@@ -890,6 +967,7 @@ xx(pvmove,
    "\t[-h|-?|--help]\n"
    "\t[-i|--interval seconds]\n"
    "\t[--noudevsync]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n "
    "\t[-v|--verbose]\n "
    "\t[--version]\n"
@@ -899,7 +977,7 @@ xx(pvmove,
    "\t[DestinationPhysicalVolume[:PhysicalExtent[-PhysicalExtent]...]...]\n",
 
    abort_ARG, alloc_ARG, atomic_ARG, autobackup_ARG, background_ARG,
-   interval_ARG, name_ARG, noudevsync_ARG, test_ARG)
+   interval_ARG, name_ARG, noudevsync_ARG, reportformat_ARG, test_ARG)
 
 xx(lvpoll,
    "Continue already initiated poll operation on a logical volume",
@@ -927,13 +1005,14 @@ xx(pvremove,
    "\t[-d|--debug]\n"
    "\t[-f[f]|--force [--force]]\n"
    "\t[-h|-?|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\t[-y|--yes]\n"
    "\tPhysicalVolume [PhysicalVolume...]\n",
 
-   force_ARG, test_ARG)
+   force_ARG, reportformat_ARG, test_ARG)
 
 xx(pvs,
    "Display information about physical volumes",
@@ -943,11 +1022,13 @@ xx(pvs,
    "\t[--aligned]\n"
    "\t[--binary]\n"
    "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
    "\t[-d|--debug]\n"
    "\t[--foreign]\n"
    "\t[-h|-?|--help]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
    "\t[--nameprefixes]\n"
    "\t[--noheadings]\n"
    "\t[--nosuffix]\n"
@@ -955,6 +1036,7 @@ xx(pvs,
    "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--rows]\n"
    "\t[--segments]\n"
    "\t[-S|--select Selection]\n"
@@ -967,11 +1049,12 @@ xx(pvs,
    "\t[--version]\n"
    "\t[PhysicalVolume [PhysicalVolume...]]\n",
 
-   aligned_ARG, all_ARG, binary_ARG, foreign_ARG, ignorelockingfailure_ARG,
-   ignoreskippedcluster_ARG, nameprefixes_ARG, noheadings_ARG, nolocking_ARG,
-   nosuffix_ARG, options_ARG, partial_ARG, readonly_ARG, rows_ARG,
-   segments_ARG, select_ARG, separator_ARG, shared_ARG, sort_ARG, trustcache_ARG,
-   unbuffered_ARG, units_ARG, unquoted_ARG)
+   aligned_ARG, all_ARG, binary_ARG, configreport_ARG, foreign_ARG,
+   ignorelockingfailure_ARG, ignoreskippedcluster_ARG, logonly_ARG,
+   nameprefixes_ARG, noheadings_ARG, nolocking_ARG, nosuffix_ARG,
+   options_ARG, partial_ARG, readonly_ARG, reportformat_ARG, rows_ARG,
+   segments_ARG, select_ARG, separator_ARG, shared_ARG, sort_ARG,
+   trustcache_ARG, unbuffered_ARG, units_ARG, unquoted_ARG)
 
 xx(pvscan,
    "List all physical volumes",
@@ -986,6 +1069,7 @@ xx(pvscan,
    "\t[--ignorelockingfailure]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-s|--short]\n"
    "\t[-u|--uuid]\n"
    "\t[-v|--verbose]\n"
@@ -993,7 +1077,8 @@ xx(pvscan,
 
    activate_ARG, available_ARG, backgroundfork_ARG, cache_long_ARG,
    exported_ARG, ignorelockingfailure_ARG, major_ARG, minor_ARG,
-   novolumegroup_ARG, partial_ARG, readonly_ARG, short_ARG, uuid_ARG)
+   novolumegroup_ARG, partial_ARG, readonly_ARG, reportformat_ARG,
+   short_ARG, uuid_ARG)
 
 xx(segtypes,
    "List available segment types",
@@ -1022,11 +1107,13 @@ xx(vgcfgbackup,
    "\t[--ignorelockingfailure]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\t[VolumeGroupName...]\n",
 
-   file_ARG, foreign_ARG, ignorelockingfailure_ARG, partial_ARG, readonly_ARG)
+   file_ARG, foreign_ARG, ignorelockingfailure_ARG, partial_ARG, readonly_ARG,
+   reportformat_ARG)
 
 xx(vgcfgrestore,
    "Restore volume group configuration",
@@ -1067,6 +1154,7 @@ xx(vgchange,
    "\t[--poll {y|n}]\n"
    "\t[--noudevsync]\n"
    "\t[--refresh]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[--sysinit]\n"
    "\t[--systemid SystemID]\n"
@@ -1091,9 +1179,9 @@ xx(vgchange,
    ignoreskippedcluster_ARG, logicalvolume_ARG, maxphysicalvolumes_ARG,
    metadataprofile_ARG, monitor_ARG, noudevsync_ARG, metadatacopies_ARG,
    vgmetadatacopies_ARG, partial_ARG, physicalextentsize_ARG, poll_ARG,
-   refresh_ARG, resizeable_ARG, resizable_ARG, select_ARG, sysinit_ARG,
-   systemid_ARG, test_ARG, uuid_ARG, lockstart_ARG, lockstop_ARG, locktype_ARG, lockopt_ARG,
-   force_ARG)
+   refresh_ARG, reportformat_ARG, resizeable_ARG, resizable_ARG, select_ARG,
+   sysinit_ARG, systemid_ARG, test_ARG, uuid_ARG, lockstart_ARG, lockstop_ARG,
+   locktype_ARG, lockopt_ARG, force_ARG)
 
 xx(vgck,
    "Check the consistency of volume group(s)",
@@ -1102,9 +1190,12 @@ xx(vgck,
    "\t[--commandprofile ProfileName]\n"
    "\t[-d|--debug]\n"
    "\t[-h|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
-   "\t[VolumeGroupName...]\n")
+   "\t[VolumeGroupName...]\n",
+
+   reportformat_ARG)
 
 xx(vgconvert,
    "Change volume group metadata format",
@@ -1118,6 +1209,7 @@ xx(vgconvert,
    "\t[--pvmetadatacopies #copies]\n"
    "\t[--metadatasize MetadataSize[bBsSkKmMgGtTpPeE]]\n"
    "\t[--bootloaderareasize BootLoaderAreaSize[bBsSkKmMgGtTpPeE]]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
@@ -1125,7 +1217,7 @@ xx(vgconvert,
 
    force_ARG, test_ARG, labelsector_ARG, bootloaderareasize_ARG,
    metadatatype_ARG, metadatacopies_ARG, pvmetadatacopies_ARG,
-   metadatasize_ARG)
+   metadatasize_ARG, reportformat_ARG)
 
 xx(vgcreate,
    "Create a volume group",
@@ -1143,6 +1235,7 @@ xx(vgcreate,
    "\t[-M|--metadatatype 1|2]\n"
    "\t[--[vg]metadatacopies #copies]\n"
    "\t[-p|--maxphysicalvolumes MaxPhysicalVolumes]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-s|--physicalextentsize PhysicalExtentSize[bBsSkKmMgGtTpPeE]]\n"
    "\t[--systemid SystemID]\n"
    "\t[-t|--test]\n"
@@ -1155,7 +1248,7 @@ xx(vgcreate,
    addtag_ARG, alloc_ARG, autobackup_ARG, clustered_ARG, maxlogicalvolumes_ARG,
    maxphysicalvolumes_ARG, metadataprofile_ARG, metadatatype_ARG,
    physicalextentsize_ARG, test_ARG, force_ARG, zero_ARG, labelsector_ARG,
-   metadatasize_ARG, pvmetadatacopies_ARG, metadatacopies_ARG,
+   metadatasize_ARG, pvmetadatacopies_ARG, reportformat_ARG, metadatacopies_ARG,
    vgmetadatacopies_ARG, dataalignment_ARG, dataalignmentoffset_ARG,
    shared_ARG, systemid_ARG, locktype_ARG, lockopt_ARG)
 
@@ -1174,6 +1267,7 @@ xx(vgdisplay,
    "\t[--nosuffix]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[--units hHbBsSkKmMgGtTpPeE]\n"
    "\t[--version]\n"
@@ -1183,16 +1277,19 @@ xx(vgdisplay,
    "\t[--aligned]\n"
    "\t[--binary]\n"
    "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
    "\t[-d|--debug]\n"
    "\t[--foreign]\n"
    "\t[-h|--help]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
    "\t[--noheadings]\n"
    "\t[--nosuffix]\n"
    "\t[-o|--options [+|-|#]Field[,Field]]\n"
    "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
    "\t[-P|--partial]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[--readonly]\n"
    "\t[--separator Separator]\n"
@@ -1203,9 +1300,10 @@ xx(vgdisplay,
    "\t[VolumeGroupName [VolumeGroupName...]]\n",
 
    activevolumegroups_ARG, aligned_ARG, binary_ARG, colon_ARG, columns_ARG,
-   foreign_ARG, ignorelockingfailure_ARG, ignoreskippedcluster_ARG,
-   noheadings_ARG, nosuffix_ARG, options_ARG, partial_ARG, readonly_ARG,
-   select_ARG, shared_ARG, short_ARG, separator_ARG, sort_ARG, unbuffered_ARG, units_ARG)
+   configreport_ARG, foreign_ARG, ignorelockingfailure_ARG,
+   ignoreskippedcluster_ARG, logonly_ARG, noheadings_ARG, nosuffix_ARG,
+   options_ARG, partial_ARG, readonly_ARG, reportformat_ARG, select_ARG,
+   shared_ARG, short_ARG, separator_ARG, sort_ARG, unbuffered_ARG, units_ARG)
 
 xx(vgexport,
    "Unregister volume group(s) from the system",
@@ -1215,12 +1313,13 @@ xx(vgexport,
    "\t[--commandprofile ProfileName]\n"
    "\t[-d|--debug]\n"
    "\t[-h|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\tVolumeGroupName [VolumeGroupName...]\n",
 
-   all_ARG, select_ARG, test_ARG)
+   all_ARG, reportformat_ARG, select_ARG, test_ARG)
 
 xx(vgextend,
    "Add physical volumes to a volume group",
@@ -1232,6 +1331,7 @@ xx(vgextend,
    "\t[-d|--debug]\n"
    "\t[-f|--force]\n"
    "\t[-h|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
@@ -1243,7 +1343,7 @@ xx(vgextend,
    force_ARG, zero_ARG, labelsector_ARG, metadatatype_ARG,
    metadatasize_ARG, pvmetadatacopies_ARG, metadatacopies_ARG,
    metadataignore_ARG, dataalignment_ARG, dataalignmentoffset_ARG,
-   restoremissing_ARG)
+   reportformat_ARG, restoremissing_ARG)
 
 xx(vgimport,
    "Register exported volume group with system",
@@ -1254,13 +1354,29 @@ xx(vgimport,
    "\t[-d|--debug]\n"
    "\t[-f|--force]\n"
    "\t[-h|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\tVolumeGroupName...\n",
 
-   all_ARG, force_ARG, select_ARG, test_ARG)
+   all_ARG, force_ARG, reportformat_ARG, select_ARG, test_ARG)
+
+xx(vgimportclone,
+   "Import a VG from cloned PVs",
+   NO_LVMETAD_AUTOSCAN,
+   "vgimportclone\n"
+   "\t[-d|--debug]\n"
+   "\t[-h|--help]\n"
+   "\t[-i|--import]\n"
+   "\t[-n|--basevgname]\n"
+   "\t[-t|--test]\n"
+   "\t[-v|--verbose]\n"
+   "\t[--version]\n"
+   "\t[PhysicalVolumePath...]\n",
+
+   basevgname_ARG, test_ARG, import_ARG)
 
 xx(vgmerge,
    "Merge volume groups",
@@ -1287,11 +1403,12 @@ xx(vgmknodes,
    "\t[-h|--help]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--refresh]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\t[VolumeGroupName...]\n",
 
-   ignorelockingfailure_ARG, refresh_ARG)
+   ignorelockingfailure_ARG, refresh_ARG, reportformat_ARG)
 
 xx(vgreduce,
    "Remove physical volume(s) from a volume group",
@@ -1304,6 +1421,7 @@ xx(vgreduce,
    "\t[-h|--help]\n"
    "\t[--mirrorsonly]\n"
    "\t[--removemissing]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-f|--force]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
@@ -1312,7 +1430,7 @@ xx(vgreduce,
    "\t[PhysicalVolumePath...]\n",
 
    all_ARG, autobackup_ARG, force_ARG, mirrorsonly_ARG, removemissing_ARG,
-   test_ARG)
+   reportformat_ARG, test_ARG)
 
 xx(vgremove,
    "Remove volume group(s)",
@@ -1323,13 +1441,14 @@ xx(vgremove,
    "\t[-f|--force]\n"
    "\t[-h|--help]\n"
    "\t[--noudevsync]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-S|--select Selection]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\tVolumeGroupName [VolumeGroupName...]\n",
 
-   force_ARG, noudevsync_ARG, select_ARG, test_ARG)
+   force_ARG, noudevsync_ARG, reportformat_ARG, select_ARG, test_ARG)
 
 xx(vgrename,
    "Rename a volume group",
@@ -1339,13 +1458,14 @@ xx(vgrename,
    "\t[--commandprofile ProfileName]\n"
    "\t[-d|--debug]\n"
    "\t[-h|--help]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-t|--test]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n"
    "\tOldVolumeGroupPath NewVolumeGroupPath |\n"
    "\tOldVolumeGroupName NewVolumeGroupName\n",
 
-   autobackup_ARG, force_ARG, test_ARG)
+   autobackup_ARG, force_ARG, reportformat_ARG, test_ARG)
 
 xx(vgs,
    "Display information about volume groups",
@@ -1355,11 +1475,13 @@ xx(vgs,
    "\t[--binary]\n"
    "\t[-a|--all]\n"
    "\t[--commandprofile ProfileName]\n"
+   "\t[--configreport ReportName]\n"
    "\t[-d|--debug]\n"
    "\t[--foreign]\n"
    "\t[-h|--help]\n"
    "\t[--ignorelockingfailure]\n"
    "\t[--ignoreskippedcluster]\n"
+   "\t[--logonly]\n"
    "\t[--nameprefixes]\n"
    "\t[--noheadings]\n"
    "\t[--nosuffix]\n"
@@ -1367,6 +1489,7 @@ xx(vgs,
    "\t[-O|--sort [+|-]key1[,[+|-]key2[,...]]]\n"
    "\t[-P|--partial]\n"
    "\t[--readonly]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[--rows]\n"
    "\t[-S|--select Selection]\n"
    "\t[--separator Separator]\n"
@@ -1378,11 +1501,12 @@ xx(vgs,
    "\t[--version]\n"
    "\t[VolumeGroupName [VolumeGroupName...]]\n",
 
-   aligned_ARG, all_ARG, binary_ARG, foreign_ARG, ignorelockingfailure_ARG,
-   ignoreskippedcluster_ARG, nameprefixes_ARG, noheadings_ARG,
-   nolocking_ARG, nosuffix_ARG, options_ARG, partial_ARG,
-   readonly_ARG, rows_ARG, select_ARG, separator_ARG, shared_ARG, sort_ARG,
-   trustcache_ARG, unbuffered_ARG, units_ARG, unquoted_ARG)
+   aligned_ARG, all_ARG, binary_ARG, configreport_ARG, foreign_ARG,
+   ignorelockingfailure_ARG, ignoreskippedcluster_ARG, logonly_ARG,
+   nameprefixes_ARG, noheadings_ARG, nolocking_ARG, nosuffix_ARG,
+   options_ARG, partial_ARG, readonly_ARG, reportformat_ARG, rows_ARG,
+   select_ARG, separator_ARG, shared_ARG, sort_ARG, trustcache_ARG,
+   unbuffered_ARG, units_ARG, unquoted_ARG)
 
 xx(vgscan,
    "Search for all volume groups",
@@ -1396,10 +1520,12 @@ xx(vgscan,
    "\t[--mknodes]\n"
    "\t[--notifydbus]\n"
    "\t[-P|--partial]\n"
+   "\t[--reportformat {basic|json}]\n"
    "\t[-v|--verbose]\n"
    "\t[--version]\n",
 
-   cache_long_ARG, ignorelockingfailure_ARG, mknodes_ARG, notifydbus_ARG, partial_ARG)
+   cache_long_ARG, ignorelockingfailure_ARG, mknodes_ARG, notifydbus_ARG,
+   partial_ARG, reportformat_ARG)
 
 xx(vgsplit,
    "Move physical volumes into a new or existing volume group",
